-- Name:	KromTargetIcons
-- Version:	0.5
-- Author:	Kromcrush of Burning Legion/Horde


-- SetRaidTarget(UnitId, icon);
-- 0 = no icon 
-- 1 = Yellow 4-point Star 
-- 2 = Orange Circle 
-- 3 = Purple Diamond 
-- 4 = Green Triangle 
-- 5 = White Crescent Moon 
-- 6 = Blue Square 
-- 7 = Red "X" Cross 
-- 8 = White Skull


local KTI_VERSION = "1.0"

local TEXTURE_PATH = "interface\\targetingframe\\ui-raidtargetingicons";
local ICON_CONST = {
	["Krom_blank"] = {
		ICON_ID			= 0,
		TEXCOORD_LEFT	= nil,
		TEXCOORD_RIGHT	= nil,
		TEXCOORD_TOP	= nil,
		TEXCOORD_BOTTOM	= nil
	},
	["Krom_star"] = {
		ICON_ID			= 1,
		TEXCOORD_LEFT	= 0.00,
		TEXCOORD_RIGHT	= 0.25,
		TEXCOORD_TOP	= 0.00,
		TEXCOORD_BOTTOM	= 0.25
	},
	["Krom_circle"] = {
		ICON_ID			= 2,
		TEXCOORD_LEFT	= 0.25,
		TEXCOORD_RIGHT	= 0.50,
		TEXCOORD_TOP	= 0.00,
		TEXCOORD_BOTTOM	= 0.25
	},
	["Krom_diamond"] = {
		ICON_ID			= 3,
		TEXCOORD_LEFT	= 0.50,
		TEXCOORD_RIGHT	= 0.75,
		TEXCOORD_TOP	= 0.00,
		TEXCOORD_BOTTOM	= 0.25
	},
	["Krom_triangle"] = {
		ICON_ID			= 4,
		TEXCOORD_LEFT	= 0.75,
		TEXCOORD_RIGHT	= 1.00,
		TEXCOORD_TOP	= 0.00,
		TEXCOORD_BOTTOM	= 0.25
	},
	["Krom_moon"] = {
		ICON_ID			= 5,
		TEXCOORD_LEFT	= 0.00,
		TEXCOORD_RIGHT	= 0.25,
		TEXCOORD_TOP	= 0.25,
		TEXCOORD_BOTTOM	= 0.50
	},
	["Krom_square"] = {
		ICON_ID			= 6,
		TEXCOORD_LEFT	= 0.25,
		TEXCOORD_RIGHT	= 0.50,
		TEXCOORD_TOP	= 0.25,
		TEXCOORD_BOTTOM	= 0.50
	},
	["Krom_cross"] = {
		ICON_ID			= 7,
		TEXCOORD_LEFT	= 0.50,
		TEXCOORD_RIGHT	= 0.75,
		TEXCOORD_TOP	= 0.25,
		TEXCOORD_BOTTOM	= 0.50
	},
	["Krom_skull"] = {
		ICON_ID			= 8,
		TEXCOORD_LEFT	= 0.75,
		TEXCOORD_RIGHT	= 1.00,
		TEXCOORD_TOP	= 0.25,
		TEXCOORD_BOTTOM	= 0.50
	}
};


-- Called when the parent frame loads
function KromTargetIcons_Head_OnLoad()
	this:RegisterForDrag("LeftButton");
	
	SlashCmdList["KROMSLASH"] = KromTargetIcons_KromSlash;
	SLASH_KROMSLASH1 = "/kromtargeticons";
	SLASH_KROMSLASH2 = "/kti";
	
	DEFAULT_CHAT_FRAME:AddMessage("KromTargetIcons v"..KTI_VERSION.." Loaded!");
	DEFAULT_CHAT_FRAME:AddMessage("Use /kti for a list of slash commands.");
end


-- Called when the icon window is loaded
function KromTargetIcons_OnLoad()
	this:RegisterEvent("VARIABLES_LOADED");
end


-- Called when slash command is parsed
function KromTargetIcons_KromSlash(cmd)
	local args = {};
	args = KromTargetIcons_GetWords(cmd);
	
	if (args[1] == "set") then
		if args[2] then
			if ICON_CONST["Krom_"..args[2]].ICON_ID then
				local iconID = ICON_CONST["Krom_"..args[2]].ICON_ID;
				SetRaidTarget("target", iconID);
			else
				DEFAULT_CHAT_FRAME:AddMessage("/kti set [ blank | star | circle | diamond | triangle | moon | square | cross | skull ]");
			end
		else
			DEFAULT_CHAT_FRAME:AddMessage("/kti set [ blank | star | circle | diamond | triangle | moon | square | cross | skull ]");
		end
		
	elseif (args[1] == "show") then
		KromTargetIcons_Head:Show();
		
	elseif (args[1] == "hide") then
		KromTargetIcons_Head:Hide();
		
	else
		DEFAULT_CHAT_FRAME:AddMessage("/kti [ set | show | hide | config ]");
	end
end


-- Loads icons
function KromTargetIcons_LoadIcon()
	this:RegisterForClicks("LeftButtonDown","RightButtonDown");
	
	local icon 		= getglobal(this:GetName());
	local iconID 	= ICON_CONST[this:GetName()].ICON_ID;
	local left 		= ICON_CONST[this:GetName()].TEXCOORD_LEFT;
	local right 	= ICON_CONST[this:GetName()].TEXCOORD_RIGHT;
	local top 		= ICON_CONST[this:GetName()].TEXCOORD_TOP;
	local bottom 	= ICON_CONST[this:GetName()].TEXCOORD_BOTTOM;
	
	local normalTexture 	= getglobal(this:GetName().."_NormalTexture");
	local pushedTexture 	= getglobal(this:GetName().."_PushedTexture");
	local highlightTexture 	= getglobal(this:GetName().."_HighlightTexture");
	
	normalTexture:SetTexCoord(left,right,top,bottom);
	pushedTexture:SetTexCoord(left,right,top,bottom);
	highlightTexture:SetTexCoord(left,right,top,bottom);
end


-- Called when one of the icon buttons is clicked
function KromTargetIcons_OnClick(arg1)
	local iconID = ICON_CONST[this:GetName()].ICON_ID;
	if (arg1 == "LeftButton") then
		SetRaidTarget("target", iconID);
	elseif (arg1 == "RightButton") then
		local iconID = ICON_CONST["Krom_blank"].ICON_ID;
		SetRaidTarget("target", iconID);
	end
end


-- Called on minimize
function KromTargetIcons_Minimize()
	if KromTargetIcons:IsShown() then
		KromTargetIcons:Hide();
	else
		KromTargetIcons:Show();
	end
end


-- Function to split string at every space
function KromTargetIcons_GetWords(str)
	local ret = {};
	local pos=0;
	while(true) do
		local word;
		_,pos,word=string.find(str, "^ *([^%s]+) *", pos+1);
		if(not word) then
			return ret;
		end
		table.insert(ret, word);
	end
end
